@@ -1,5 +1,6 @@
 import os
 import datetime
+import logging
 import pyhcup
 
 from django.utils.timezone import utc
@@ -11,6 +12,10 @@ from django.conf import settings
 from djhcup_core.defaults import DATETIME_FORMAT
 
 
+# start a logger
+default_logger = logging.getLogger('default')
+
+
 # Create your models here.
 class State(models.Model):
     abbreviation = models.CharField(max_length=2, blank=False,
@@ -247,6 +252,8 @@ class ImportQueue(models.Model):
                       ('SUCCESS', 'Completed successfully'),
                       ]
     status = models.CharField(max_length=15, blank=False, null=True, default='NEW', choices=STATUS_CHOICES)
+    message = models.TextField(blank=True, null=True, default=None)
+    message_at = models.DateTimeField(blank=True, null=True, default=None)
     celery_task_id = models.TextField(blank=True, null=True, default=None)
     
     #meta cruft
@@ -256,14 +263,17 @@ class ImportQueue(models.Model):
     voided_at = models.DateTimeField(blank=True, null=True, default=None)
     #voided_by = models.ForeignKey(django user object) #unimplemented
     
+    
     def _hr_start(self):
         return self.start.strftime(DATETIME_FORMAT)
     hr_start = property(_hr_start)
     
+    
     def _hr_complete(self):
         return self.complete.strftime(DATETIME_FORMAT)
     hr_complete = property(_hr_complete)
     
+    
     def _runtime(self):
         if self.start and self.complete:
             return self.complete - self.start
@@ -271,6 +281,7 @@ class ImportQueue(models.Model):
             return None
     runtime = property(_runtime)
     
+    
     def _hr_runtime(self):
         """File runtime in hours"""
         if self.runtime is not None:
@@ -280,6 +291,7 @@ class ImportQueue(models.Model):
             return None
     hr_runtime = property(_hr_runtime)
     
+    
     def _est_runtime(self):
         # default to average across all SID CORE state-years as of 2014-03-28
         width = 164
@@ -304,16 +316,48 @@ class ImportQueue(models.Model):
         verbose_name_plural = 'enqueued items'
     
     
-    def fail(self):
+    def log(self, message, level='INFO', status=None, logger=None):
+        """Emit a log message at the specified log level and optionally update the ImportQueue object status attribute.
+        """
+        
+        if level not in ['NOTSET', 'DEBUG', 'INFO', 'WARNING', 'ERROR', 'CRITICAL']:
+            raise Exception("Invalid log level specified: %s" % level)
+        else:
+            level = getattr(logging, level)
+        
+        if logger is None:
+            logger = default_logger
+        
+        if status is not None:
+            self.status = status
+        
+        self.message = message
+        self.save()
+        
+        logger.log(level, message)
+        return True
+    
+    
+    def fail(self, message=None, logger=None):
         self.status = 'FAILED'
         self.complete = datetime.datetime.utcnow().replace(tzinfo=utc)
         self.save()
+        
+        if message is not None:
+            self.log(message, logger=logger)
+        
+        return True
     
     
-    def success(self):
+    def success(self, message=None, logger=None, level='ERROR'):
         self.status = 'SUCCESS'
         self.complete = datetime.datetime.utcnow().replace(tzinfo=utc)
         self.save()
+        
+        if message is not None:
+            self.log(message, level=level, logger=logger)
+        
+        return True
     
     
     def successful(self):
@@ -362,7 +406,6 @@ class ImportQueue(models.Model):
                     )
                 col.save()
                 cols_saved += 1
-                
         else:
             raise Exception('No loadfile parser associated with top-level source %s' % tls)
         
@@ -381,7 +424,6 @@ class ImportQueue(models.Model):
         else:
             raise Exception('No loadfile parser associated with top-level source %s' % tls)
         
-        
         loadfile = self.file.loadfile
         
         if loadfile is None:
