@@ -234,24 +234,23 @@ def pg_import_file(self, importqueue_pk, drop_intermediate_tables=True):
     load = ImportQueue.objects.get(pk=importqueue_pk)
     load.status = 'RECEIVED'
     load.celery_task_id = self.request.id
-    load.save()
-    
-    logger.info('Received for import with psycopg2: %s' % (load))
-    
-    destination = load.batch.destination
-
-    # proceed with making the file happen
-    load.status = 'IN PROCESS'
     load.start = datetime.datetime.utcnow().replace(tzinfo=utc)
     load.save()
+    load.log('Beginning import with psycopg2',
+             level='INFO', logger=logger, status='IN PROCESS')
     
-    logger.info('Begin import: %s' % (load))
+    destination = load.batch.destination
+    
+    load.log('Begin import',
+             level='INFO', logger=logger)
     
     cols_saved = load.record_columns()
     if cols_saved > 0:
-        logger.info('Columns saved: %s for %s' % (cols_saved, load))
+        load.log('Columns saved: %s' % (load),
+                level='INFO', logger=logger)
     else:
-        logger.info('No columns saved for %s' % (load))
+        load.log('No columns saved',
+                level='WARNING', logger=logger)
     
     table = destination.name
     schema = destination.schema
@@ -277,57 +276,80 @@ def pg_import_file(self, importqueue_pk, drop_intermediate_tables=True):
     # let 'er rip
     meta = load.get_meta()
     
-    logger.info('Creating raw import table via pg_rawload(): %s' % (load))
+    load.log('Creating raw import table via pg_rawload()',
+            level='INFO', logger=logger)
     rawload = pg_rawload(cnxn, handle, meta)
-    logger.info('Raw import table %s populated: %s' % (rawload, load))
+    load.log('Raw import table %s populated' % (rawload),
+            level='INFO', logger=logger)
     
     if load.file.file_type.source.abbreviation in pyhcup.parser.LONG_MAPS.keys():
         pk_fields = None
-        logger.info('Staging will be done with no primary key: %s' % (load))
+        load.log('Staging will be done with no primary key',
+                level='INFO', logger=logger)
     else:
         pk_fields = ['key', 'state', 'year']
-        logger.info('Staging will be done with primary key %s: %s' % (pk_fields, load))
+        load.log('Staging will be done with primary key %s' % (pk_fields),
+                level='INFO', logger=logger)
     
-    logger.info('Creating staging table via pg_staging(): %s' % (load))
+    load.log('Creating staging table via pg_staging()',
+            level='INFO', logger=logger)
     staging = pg_staging(cnxn, rawload, meta, state, year, pk_fields=pk_fields)
-    logger.info('Staging table %s populated: %s' % (staging[0], load))
+    load.log('Staging table populated: %s' % (staging[0]),
+            level='INFO', logger=logger)
     
     
     if dsabbr in ['CHGS'] and not meta_is_long(meta):
         # wide charges should get wide-to-long shoveled
         category = dsabbr
-        logger.info('This is a wide-to-long pg load: %s' % (load))
-        logger.info('Inserting contents of staging table %s to master table %s: %s' % (staging[0], table, load))
+        load.log('This is a wide-to-long pg load',
+                level='INFO', logger=logger)
+        #logger.info()
+        load.log('Inserting contents of staging table %s to master table %s' % (staging[0], table),
+                level='INFO', logger=logger)
         affected_rows = pg_wtl_shovel(cnxn, meta, category, staging[0], table)
-        logger.info('Inserted contents of staging table %s to master table %s (%s rows): %s' % (staging[0], table, affected_rows, load))
+        #logger.info('Inserted contents of staging table %s to master table %s (%s rows): %s' % (staging[0], table, affected_rows, load))
+        load.log('Inserted contents of staging table %s to master table %s (%s rows)' % (staging[0], table, affected_rows),
+                level='INFO', logger=logger)
     
     else:
         fields = [x for x in meta.field if x.lower() not in ['state', 'year']]
         fields += ['state', 'year']
         
-        logger.info('Inserting contents of staging table %s to master table %s: %s' % (staging[0], table, load))
+        #logger.info('Inserting contents of staging table %s to master table %s: %s' % (staging[0], table, load))
+        load.log('Inserting contents of staging table %s to master table %s' % (staging[0], table),
+                level='INFO', logger=logger)
         affected_rows = pg_shovel(cnxn, staging[0], table, fields)
         logger.info('Inserted contents of staging table %s to master table %s (%s rows): %s' % (staging[0], table, affected_rows, load))
+        load.log('Inserted contents of staging table %s to master table %s (%s rows)' % (staging[0], table, affected_rows),
+                level='INFO', logger=logger)
         
-        if drop_intermediate_tables:
-            drop_targets = [rawload, staging[0]]
-            logger.info('Dropping intermediate tables %s: %s' % (drop_targets, load))
-            for dtbl in drop_targets:
-                logger.info('Dropping %s as part of load %s' % (dtbl, load))
-                drop_result = pg_drop(cnxn, dtbl)
-                if drop_result == True:
-                    logger.info('Successfully dropped intermediate table %s: %s' % (dtbl, load))
-                else:
-                    logger.error('Failed to drop %s: %s' % (dtbl, load))
+    if drop_intermediate_tables:
+        drop_targets = [rawload, staging[0]]
+        #logger.info('Dropping intermediate tables %s: %s' % (drop_targets, load))
+        load.log('Dropping intermediate tables: %s' % (drop_targets),
+                level='INFO', logger=logger)
+        for dtbl in drop_targets:
+            #logger.info('Dropping intermediate table %s: %s' % (dtbl, load))
+            load.log('Dropping intermediate table: %s' % (dtbl),
+                    level='INFO', logger=logger)
+            drop_result = pg_drop(cnxn, dtbl)
+            if drop_result == True:
+                logger.info('Successfully dropped intermediate table %s: %s' % (dtbl, load))
+                load.log('Successfully dropped intermediate table: %s' % (dtbl),
+                        level='INFO', logger=logger)
+            else:
+                logger.error('Failed to drop %s: %s' % (dtbl, load))
+                load.log('Failed to drop: %s' % (dtbl),
+                        level='ERROR', logger=logger)
     
     # affected_rows will evaluate un-True in the case of any troubles
     if affected_rows:
-        load.success()
-        logger.info('Import complete: %s (%s rows)' % (load, affected_rows))
+        load.success('Import complete (%s rows)' % (affected_rows))
+        #logger.info('Import complete: %s (%s rows)' % (load, affected_rows))
         return True
     else:
-        load.fail()
-        logger.error('Import failed: %s' % load)
+        load.fail('Import failed')
+        #logger.error('Import failed: %s' % load)
         return False
 
 
@@ -524,7 +546,7 @@ def import_complete(self, result_lst, importqueue_pk):
         raise self.retry(exc=Exception('Import not yet complete: %s' % iq))
 
 
-@celery.shared_task(bind=True, max_retries=None, default_retry_delay=600)# default_retry_delay=60)
+@celery.shared_task(bind=True, max_retries=None, default_retry_delay=900)# default_retry_delay=60)
 def batch_complete(self, batch_pk):
     """Checks to see if each item in the batch has a completion timestamp in db, and updates batch db entry to reflect success/failure of overall batch.
     """
